From ff64d35f59e1a12f01f8120f52de20a92a94cfec Mon Sep 17 00:00:00 2001
From: colin <colin@git@nixc.us>
Date: Thu, 12 Dec 2024 12:36:13 -0500
Subject: [PATCH] Update install.sh

---
 install.sh | 15 ++++++---------
 1 file changed, 6 insertions(+), 9 deletions(-)

diff --git a/install.sh b/install.sh
index d4e8f4f..56a6d03 100644
--- a/install.sh
+++ b/install.sh
@@ -21,7 +21,6 @@ library_names=(
   "BOSL"
   "MCAD"
   "nutsnbolts"
-  "openscad-fillets"
   "openscad-model-library"
   "OpenSCAD-Arduino-Mounting-Library"
   "BezierScad"
@@ -32,24 +31,22 @@ library_urls=(
   "https://github.com/revarbat/BOSL.git"
   "https://github.com/openscad/MCAD.git"
   "https://github.com/JohK/nutsnbolts.git"
-  "https://github.com/jfhbrook/openscad-fillets.git"
   "https://github.com/cznewt/openscad-model-library.git"
   "https://github.com/kellyegan/OpenSCAD-Arduino-Mounting-Library.git"
   "https://github.com/chadkirby/BezierScad.git"
   "https://github.com/SebiTimeWaster/Chamfers-for-OpenSCAD.git"
 )
 
 # Clone or update each library
 for ((i = 0; i < ${#library_names[@]}; i++)); do
   lib="${library_names[$i]}"
   url="${library_urls[$i]}"
-  if ! [ -d "$lib" ]; then
-    git clone "$url" "$lib"
-  else
-    cd "$lib"
-    git pull
-    cd ..
+  if [ -d "$lib" ]; then
+    echo "Removing existing directory for $lib..."
+    rm -rf "$lib"
   fi
+  echo "Cloning $lib from $url..."
+  git clone "$url" "$lib"
 done
 
 # Verify OpenSCAD installation
@@ -32,24 +31,22 @@ library_urls=(
 )
 
-# Clone or update each library
+# Clone or update each library (force cloning)
 for ((i = 0; i < ${#library_names[@]}; i++)); do
   lib="${library_names[$i]}"